package com.ruoyi.ems.service;

import java.util.List;
import com.ruoyi.ems.domain.ElecPgSupplyH;

/**
 * 电网供应计量-小时Service接口
 * 
 * @author ruoyi
 * @date 2024-08-09
 */
public interface IElecPgSupplyHService
{
    /**
     * 查询电网供应计量-小时
     * 
     * @param id 电网供应计量-小时主键
     * @return 电网供应计量-小时
     */
     ElecPgSupplyH selectPgSupplyHById(Long id);

    /**
     * 查询电网供应计量-小时列表
     * 
     * @param pgSupplyH 电网供应计量-小时
     * @return 电网供应计量-小时集合
     */
     List<ElecPgSupplyH> selectPgSupplyHList(ElecPgSupplyH pgSupplyH);

    /**
     * 新增电网供应计量-小时
     * 
     * @param pgSupplyH 电网供应计量-小时
     * @return 结果
     */
     int insertPgSupplyH(ElecPgSupplyH pgSupplyH);

    /**
     * 修改电网供应计量-小时
     * 
     * @param pgSupplyH 电网供应计量-小时
     * @return 结果
     */
     int updatePgSupplyH(ElecPgSupplyH pgSupplyH);

    /**
     * 批量删除电网供应计量-小时
     * 
     * @param ids 需要删除的电网供应计量-小时主键集合
     * @return 结果
     */
     int deletePgSupplyHByIds(Long[] ids);

    /**
     * 删除电网供应计量-小时信息
     * 
     * @param id 电网供应计量-小时主键
     * @return 结果
     */
     int deletePgSupplyHById(Long id);
}
